@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2012 by the Quassel Project                        *
+ *   Copyright (C) 2005-2013 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,12 +15,14 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #ifndef KNOTIFICATIONBACKEND_H_
 #define KNOTIFICATIONBACKEND_H_
 
+#include <QPointer>
+
 #include "abstractnotificationbackend.h"
 #include "settingspage.h"
 #include "systemtray.h"
@@ -28,44 +30,48 @@
 class KNotification;
 class KNotifyConfigWidget;
 
-class KNotificationBackend : public AbstractNotificationBackend {
-  Q_OBJECT
+class KNotificationBackend : public AbstractNotificationBackend
+{
+    Q_OBJECT
 
 public:
-  KNotificationBackend(QObject *parent = 0);
+    KNotificationBackend(QObject *parent = 0);
 
-  void notify(const Notification &);
-  void close(uint notificationId);
-  virtual SettingsPage *createConfigWidget() const;
+    void notify(const Notification &);
+    void close(uint notificationId);
+    virtual SettingsPage *createConfigWidget() const;
 
 private slots:
-  void notificationActivated();
-  void notificationActivated(SystemTray::ActivationReason);
-  void notificationActivated(uint notificationId);
+    void notificationActivated();
+    void notificationActivated(SystemTray::ActivationReason);
+    void notificationActivated(uint notificationId);
 
 private:
-  class ConfigWidget;
+    class ConfigWidget;
 
-  void removeNotificationById(uint id);
-  void updateToolTip();
+    void removeNotificationById(uint id);
+    void updateToolTip();
 
-  QList<QPair<uint, QPointer<KNotification> > > _notifications;
+    QList<QPair<uint, QPointer<KNotification> > > _notifications;
 };
 
-class KNotificationBackend::ConfigWidget : public SettingsPage {
-  Q_OBJECT
+
+class KNotificationBackend::ConfigWidget : public SettingsPage
+{
+    Q_OBJECT
 
 public:
-  ConfigWidget(QWidget *parent = 0);
+    ConfigWidget(QWidget *parent = 0);
 
-  void save();
-  void load();
+    void save();
+    void load();
 
 private slots:
-  void widgetChanged(bool);
+    void widgetChanged(bool);
 
 private:
-  KNotifyConfigWidget *_widget;
+    KNotifyConfigWidget *_widget;
 };
 
+
 #endif
