@@ -122,7 +122,7 @@ private slots:
     void showNotificationsDlg();
     void showIgnoreList(QString newRule = QString());
     void showShortcutsDlg();
-    void toggleFullscreen();
+    void onFullScreenToggled();
 
     void handleCoreConnectionError(const QString &errorMsg);
     void userAuthenticationRequired(CoreAccount *, bool *valid, const QString &errorMessage);
@@ -152,6 +152,9 @@ private slots:
 
     void saveMenuBarStatus(bool enabled);
     void saveStatusBarStatus(bool enabled);
+#ifdef Q_WS_MAC
+    void saveMainToolBarStatus(bool enabled);
+#endif
 
     void loadLayout();
     void saveLayout();
